@@ -9,7 +9,7 @@ use JSON::PP qw( encode_json );
 use Encode qw( encode_utf8 );
 
 # ABSTRACT: Dist::Zilla initialization tasks for Plicease
-our $VERSION = '2.06'; # VERSION
+our $VERSION = '2.07'; # VERSION
 
 
 with 'Dist::Zilla::Role::AfterMint';
@@ -213,19 +213,6 @@ sub gather_files_tests
 {
   my($self, $arg) = @_;
   
-  if($self->include_tests)
-  {
-    my $source = Dist::Zilla::MintingProfile::Author::Plicease->profile_dir->subdir(qw( default skel xt release ));
-    foreach my $test ($source->children)
-    {
-      my $file = Dist::Zilla::File::FromCode->new({
-        name => "xt/release/" . $test->basename,
-        code => sub { $test->slurp(iomode => '<:encoding(UTF-8)') },
-      });
-      $self->add_file($file);
-    }
-  }
-  
   my $name = $self->zilla->name;
   $name =~ s{-}{::}g;
 
@@ -356,7 +343,7 @@ Dist::Zilla::Plugin::Author::Plicease::Init2 - Dist::Zilla initialization tasks
 
 =head1 VERSION
 
-version 2.06
+version 2.07
 
 =head1 DESCRIPTION
 
