@@ -4,7 +4,7 @@ use 5.008001;
 use Moose;
 
 # ABSTRACT: Special prereq handling
-our $VERSION = '2.06'; # VERSION
+our $VERSION = '2.07'; # VERSION
 
 
 with 'Dist::Zilla::Role::BeforeRelease';
@@ -136,6 +136,8 @@ sub register_prereqs
     Test::Exit                            0.11
     Test2                                 1.302015
     Test2::Suite                          0.000030
+    Clustericious                         1.20
+    Test::Clustericious::Cluster          0.31
   );
   
   $prereqs = $self->zilla->prereqs->as_string_hash;
@@ -255,7 +257,7 @@ Dist::Zilla::Plugin::Author::Plicease::SpecialPrereqs - Special prereq handling
 
 =head1 VERSION
 
-version 2.06
+version 2.07
 
 =head1 SYNOPSIS
 
