@@ -10,7 +10,7 @@ use Data::Section { installer => method_installer }, -setup;
 use Dist::Zilla::MintingProfile::Author::Plicease;
 
 # ABSTRACT: add author only release tests to xt/release
-our $VERSION = '2.06'; # VERSION
+our $VERSION = '2.07'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileGatherer';
@@ -177,7 +177,7 @@ Dist::Zilla::Plugin::Author::Plicease::Tests - add author only release tests to
 
 =head1 VERSION
 
-version 2.06
+version 2.07
 
 =head1 SYNOPSIS
 
@@ -228,8 +228,9 @@ use File::Spec;
 chdir(File::Spec->catdir($FindBin::Bin, File::Spec->updir, File::Spec->updir));
 
 unshift @Test::Strict::MODULES_ENABLING_STRICT,
-  'SIPS',
-  'Test2::Bundle::SIPS';
+  'sips',
+  'Test2::Bundle::SIPS',
+  'Test2::Bundle::Extended';
 note "enabling strict = $_" for @Test::Strict::MODULES_ENABLING_STRICT;
 
 all_perl_files_ok( grep { -e $_ } qw( bin lib t Makefile.PL ));
